DartGraphicBuilder class

图像生成器

Constructors

DartGraphicBuilder({required String path, DartGraphicSize? size, int? maxWidth})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
maxWidth → int?
final
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → DartGraphicSize?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override